@@ -55,6 +55,9 @@ Control *config_control = NULL;
 Item *config_item = NULL;
 int num_items = 0;
 
+static GtkWidget *menudialog = NULL; /* keep track of this for signal 
+					handling */
+
 static GtkWidget *dialog;
 
 static int id_callback;
@@ -1021,7 +1024,6 @@ panel_item_create_options (Control * control, GtkContainer * container,
 GtkWidget *
 create_menu_item_dialog (Item * mi)
 {
-    const char *title;
     GtkWidget *dlg;
     GtkWidget *main_vbox;
     GtkWidget *frame;
@@ -1072,20 +1074,11 @@ create_menu_item_dialog (Item * mi)
     return dlg;
 }
 
-static void
-reposition_popup (PanelPopup * pp)
-{
-    if (pp->detached)
-        return;
-
-    gtk_button_clicked (GTK_BUTTON (pp->button));
-    gtk_button_clicked (GTK_BUTTON (pp->button));
-}
-
 void
 edit_menu_item_dialog (Item * mi)
 {
     GtkWidget *dlg;
+    GtkWidget **dlg_ptr;
     PanelPopup *pp = mi->parent;
     int response = GTK_RESPONSE_NONE;
 
@@ -1093,10 +1086,12 @@ edit_menu_item_dialog (Item * mi)
 
     num_items = g_list_length (pp->items);
 
-    dlg = create_menu_item_dialog (mi);
-
+    menudialog = dlg = create_menu_item_dialog (mi);
     dialog = dlg;
 
+    dlg_ptr = &menudialog;
+    g_object_add_weak_pointer(G_OBJECT(dlg), (gpointer*)dlg_ptr);
+    
     gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
     response = gtk_dialog_run (GTK_DIALOG (dlg));
 
@@ -1108,7 +1103,7 @@ edit_menu_item_dialog (Item * mi)
 	pp->items = g_list_remove (pp->items, mi);
 	item_free (mi);
 
-	reposition_popup (pp);
+	reposition_current_popup ();
     }
 
     gtk_widget_destroy (dlg);
@@ -1128,7 +1123,15 @@ add_menu_item_dialog (PanelPopup * pp)
     mi->pos = 0;
 
     panel_popup_add_item (pp, mi);
-    reposition_popup (pp);
+    reposition_current_popup ();
 
     edit_menu_item_dialog (mi);
 }
+
+void
+destroy_menu_dialog(void)
+{
+    if (menudialog)
+	gtk_dialog_response(GTK_DIALOG(menudialog), GTK_RESPONSE_OK);
+}
+
